@@ -148,8 +148,27 @@ class ApiBase:
 
         return errormessages
 
+    def __post_request_for_raw_response(self, dict_body: dict, api_url: str):
+        """Create an HTTP post request to get a raw response.
+
+        Parameters:
+            data (dict): HTTP POST body data for the wanted API.
+            api_url (str): Url for the wanted API endpoint.
+
+        Returns:
+            A requests.Response object.
+        """
+
+        api_headers = {
+            'content-type': 'application/xml'
+        }
+        body = xmltodict.unparse(dict_body)
+
+        return requests.post(api_url, headers=api_headers, data=body.encode('utf-8'))
+
+
     def __post_request(self, dict_body: dict, api_url: str):
-        """Create a HTTP post request.
+        """Create an HTTP post request and handle HTTP errors.
 
         Parameters:
             data (dict): HTTP POST body data for the wanted API.
@@ -159,17 +178,12 @@ class ApiBase:
             A response from the request (dict).
         """
 
-        api_headers = {
-            'content-type': 'application/xml'
-        }
-        body = xmltodict.unparse(dict_body)
+        raw_response = self.__post_request_for_raw_response(dict_body, api_url)
 
-        response = requests.post(api_url, headers=api_headers, data=body)
-
-        parsed_xml = xmltodict.parse(response.text, force_list={self.__dimension})
+        parsed_xml = xmltodict.parse(raw_response.text, force_list={self.__dimension})
         parsed_response = json.loads(json.dumps(parsed_xml))
 
-        if response.status_code == 200:
+        if raw_response.status_code == 200:
             if parsed_response['response']['control']['status'] == 'success':
                 api_response = parsed_response['response']['operation']
 
@@ -192,22 +206,22 @@ class ApiBase:
 
                 raise WrongParamsError('Error during {0}'.format(api_response['result']['function']), exception_msg)
 
-        if response.status_code == 400:
+        if raw_response.status_code == 400:
             raise WrongParamsError('Some of the parameters are wrong', parsed_response)
 
-        if response.status_code == 401:
+        if raw_response.status_code == 401:
             raise InvalidTokenError('Invalid token / Incorrect credentials', parsed_response)
 
-        if response.status_code == 403:
+        if raw_response.status_code == 403:
             raise NoPrivilegeError('Forbidden, the user has insufficient privilege', parsed_response)
 
-        if response.status_code == 404:
+        if raw_response.status_code == 404:
             raise NotFoundItemError('Not found item with ID', parsed_response)
 
-        if response.status_code == 498:
+        if raw_response.status_code == 498:
             raise ExpiredTokenError('Expired token, try to refresh it', parsed_response)
 
-        if response.status_code == 500:
+        if raw_response.status_code == 500:
             raise InternalServerError('Internal server error', parsed_response)
 
         raise SageIntacctSDKError('Error: {0}'.format(parsed_response))
@@ -258,6 +272,12 @@ class ApiBase:
 
         return self.__construct_post_payload(data)
 
+    def update(self, data: Dict):
+        if self.__dimension in ('CCTRANSACTION', 'EPPAYMENT'):
+            return self.__construct_update_payload(data)
+
+        return self.__construct_update_payload(data)
+
     def __construct_post_payload(self, data: Dict):
         payload = {
             'create': {
@@ -267,6 +287,15 @@ class ApiBase:
 
         return self.format_and_send_request(payload)
 
+    def __construct_update_payload(self, data: Dict):
+        payload = {
+            'update': {
+                self.__dimension: data
+            }
+        }
+
+        return self.format_and_send_request(payload)
+
     def __construct_post_legacy_payload(self, data: Dict):
         payload = {
             self.__post_legacy_method: data
@@ -414,16 +443,17 @@ class ApiBase:
             if len(and_filter) > 1:
                 formatted_filter = {'and': {}}
                 for operator, field, value in and_filter:
-                    formatted_filter['and'].setdefault(operator, {}).update({'field': field, 'value': value})
+                    formatted_filter['and'].setdefault(operator, []).append({'field': field, 'value': value})
             else:
                 formatted_filter = {}
                 for operator, field, value in and_filter:
                     formatted_filter.setdefault(operator, {}).update({'field': field, 'value': value})
+
         elif or_filter:
             if len(or_filter) > 1:
                 formatted_filter = {'or': {}}
                 for operator, field, value in or_filter:
-                    formatted_filter['or'].setdefault(operator, {}).update({'field': field, 'value': value})
+                    formatted_filter['or'].setdefault(operator, []).append({'field': field, 'value': value})
             else:
                 formatted_filter = {}
                 for operator, field, value in or_filter:
